@@ -67,7 +67,7 @@ def test_timeout():
     def f(x):
         if x == 2:
             while True:
-                time.sleep(0.1)
+                time.sleep(0.02)
 
         return x
 
@@ -88,7 +88,12 @@ def test_worker_info():
     def _lambda(x, index):
         return index
 
-    nums_pl = pl.sync.map(_lambda, nums, on_start=on_start, workers=n_workers,)
+    nums_pl = pl.sync.map(
+        _lambda,
+        nums,
+        on_start=on_start,
+        workers=n_workers,
+    )
     nums_pl = set(nums_pl)
 
     assert nums_pl.issubset(set(range(n_workers)))
@@ -109,7 +114,11 @@ def test_kwargs():
         namespace.on_done = y
 
     nums_pl = pl.sync.map(
-        lambda x, y: y, nums, on_start=on_start, on_done=on_done, workers=n_workers,
+        lambda x, y: y,
+        nums,
+        on_start=on_start,
+        on_done=on_done,
+        workers=n_workers,
     )
     nums_pl = list(nums_pl)
 
@@ -139,6 +148,8 @@ def test_map_square_event_end(nums):
     )
     nums_pl = list(nums_pl)
 
+    time.sleep(0.1)
+
     assert namespace.x == 2
     assert namespace.done == True
     assert namespace.active_workers == 0
