@@ -184,7 +184,7 @@ def test_timeout():
     async def f(x):
         if x == 2:
             while True:
-                await asyncio.sleep(0.1)
+                await asyncio.sleep(0.02)
 
         return x
 
@@ -266,7 +266,11 @@ def test_kwargs():
         namespace.on_done = y
 
     nums_pl = pl.task.map(
-        lambda x, y: y, nums, on_start=on_start, on_done=on_done, workers=n_workers,
+        lambda x, y: y,
+        nums,
+        on_start=on_start,
+        on_done=on_done,
+        workers=n_workers,
     )
     nums_pl = list(nums_pl)
 
@@ -290,7 +294,11 @@ async def test_kwargs_async():
         namespace.on_done = y
 
     nums_pl = pl.task.map(
-        lambda x, y: y, nums, on_start=on_start, on_done=on_done, workers=n_workers,
+        lambda x, y: y,
+        nums,
+        on_start=on_start,
+        on_done=on_done,
+        workers=n_workers,
     )
     nums_pl = await nums_pl
 
@@ -320,6 +328,8 @@ def test_map_square_event_end(nums: tp.List[int]):
     )
     nums_pl = list(nums_pl)
 
+    time.sleep(0.1)
+
     assert namespace.x == 2
     assert namespace.done == True
     assert namespace.active_workers == 0
@@ -348,6 +358,8 @@ async def test_map_square_event_end_async(nums: tp.List[int]):
     )
     nums_pl = await nums_pl
 
+    await asyncio.sleep(0.1)
+
     assert namespace.x == 2
     assert namespace.done == True
     assert namespace.active_workers == 0
@@ -406,3 +418,27 @@ async def test_error_handling_async():
         error = e
 
     assert isinstance(error, MyError)
+
+
+def test_maxsize():
+
+    namespace = pl.task.utils.Namespace(count=0)
+
+    def f(x) -> tp.Any:
+        namespace.count += 1
+        return x
+
+    stage = pl.task.map(f, range(20))
+    stage = pl.task.to_iterable(stage, maxsize=3)
+
+    iterator = iter(stage)
+    next(iterator)
+
+    time.sleep(0.1)
+
+    # + 1 element which was yieled on next(...)
+    # + 3 elements which are on the queue.
+    # + 1 element which it pending to be put.
+    # -------------------------------------------
+    # + 5 total
+    assert namespace.count == 5
