@@ -61,6 +61,36 @@ class Worker(tp.Generic[T]):
     process: tp.Optional[Future] = None
     is_done: bool = False
 
+    @classmethod
+    def create(
+        cls,
+        process_fn: ProcessFn,
+        timeout: float,
+        stage_params: StageParams,
+        main_queue: IterableQueue,
+        on_start: tp.Optional[tp.Callable[..., tp.Union[Kwargs, tp.Awaitable[Kwargs]]]],
+        on_done: tp.Optional[tp.Callable[..., tp.Union[Kwargs, tp.Awaitable[Kwargs]]]],
+        f_args: tp.List[str],
+        tasks: "TaskPool",
+        process: tp.Optional[Future] = None,
+        is_done: bool = False,
+    ) -> "Worker":
+        worker = cls(
+            process_fn=process_fn,
+            timeout=timeout,
+            stage_params=stage_params,
+            main_queue=main_queue,
+            on_start=on_start,
+            on_done=on_done,
+            f_args=f_args,
+            process=process,
+            tasks=tasks,
+        )
+
+        assert worker.timeout == tasks.timeout
+
+        return worker
+
     async def __call__(self):
 
         worker_info = WorkerInfo(index=0)
@@ -107,7 +137,8 @@ class Worker(tp.Generic[T]):
             if self.on_done is not None:
 
                 kwargs.setdefault(
-                    "stage_status", StageStatus(),
+                    "stage_status",
+                    StageStatus(),
                 )
 
                 coro = self.on_done(
@@ -121,14 +152,19 @@ class Worker(tp.Generic[T]):
                 if isinstance(coro, tp.Awaitable):
                     await coro
 
+            await self.stage_params.output_queues.worker_done()
+
         except asyncio.CancelledError:
             pass
         except BaseException as e:
+            # print("ERRORRRR", e)
+            # import sys, traceback
+            # exception_type, _exception, _traceback = sys.exc_info()
+            # traceback.print_exception(exception_type, _exception, _traceback)
             await self.main_queue.raise_exception(e)
         finally:
-            self.tasks.stop()
-            await self.stage_params.output_queues.done()
             self.is_done = True
+            self.tasks.stop()
 
     def start(self):
         [self.process] = start_workers(self)
@@ -138,8 +174,12 @@ class Worker(tp.Generic[T]):
         if self.process is None:
             return
 
+        def cancel():
+            self.process.cancel()
+            # self.is_done = True
+
         self.tasks.stop()
-        utils.run_function_in_loop(self.process.cancel)
+        utils.run_function_in_loop(cancel)
 
 
 class Applicable(pypeln_utils.Protocol):
@@ -165,14 +205,14 @@ class StageStatus(tp.NamedTuple):
     @property
     def done(self) -> bool:
         """
-        `bool` : `True` if all workers finished. 
+        `bool` : `True` if all workers finished.
         """
         return True
 
     @property
     def active_workers(self):
         """
-        `int` : Number of active workers. 
+        `int` : Number of active workers.
         """
         return 0
 
@@ -238,8 +278,10 @@ class TaskPool:
         self.tasks.clear()
 
     async def join(self):
-        self.closed = True
-        await asyncio.gather(*self.tasks)
+        try:
+            await asyncio.gather(*self.tasks)
+        finally:
+            self.closed = True
 
     async def __aenter__(self):
         return self
